@@ -3,6 +3,7 @@ from datetime import timedelta
 from datetime import datetime
 from typing import *
 from .hash_utils import *
+from .dynimport import get_abstract_import,call_for_all_tabs
 from .json_utils import (unified_json_loader,
                          find_keys,
                          get_key_values_from_path,
@@ -120,7 +121,7 @@ from .type_utils import (make_bool,
                          is_any_instance,
                          break_string
                          )
-get_all_types = get_all_file_types
+get_media_types = get_all_types = get_all_file_types
 from .math_utils import (convert_to_percentage,
                          exponential,
                          get_percentage,
@@ -143,7 +144,7 @@ from .parse_utils import (num_tokens_from_string,
 
 from .log_utils import get_caller_info,get_logFile,print_or_log,get_json_call_response,initialize_call_log
 from .error_utils import try_func
-from .class_utils import alias,get_class_inputs
+from .class_utils import alias,get_class_inputs,get_set_attr
 from .robust_reader import *
 
 
